@@ -1,4 +1,5 @@
 from datetime import datetime, timedelta
+import dateutil.relativedelta
 import time
 import pandas as pd
 from sqlalchemy import create_engine
@@ -72,19 +73,26 @@ class hora:
    def __init__(self):
       self.nada=0
 
-   def get(self):
+   def get(self,asString=True):
       """
       :return: la hora
       :rtype: string
       """
-      return datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+      if(asString):
+         return datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+      else:
+         return datetime.now()
 
-   def hoy(self):
+
+   def hoy(self,asString=True):
       """
       :return: la fecha actual
       :rtype: string
       """
-      return datetime.now().strftime("%Y-%m-%d")
+      if(asString):
+         return datetime.now().strftime("%Y-%m-%d")
+      else:
+         return self.get(True) - dateutil.relativedelta.relativedelta(days=1)
 
    def ayer(self):
       """
